@@ -407,9 +407,9 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result);
-        $this->assertInternalType('array', $result[0]);
-        $this->assertInternalType('array', $result[1]);
+        $this->assertIsArray($result);
+        $this->assertIsArray($result[0]);
+        $this->assertIsArray($result[1]);
 
         // first user => 2 phonenumbers
         $this->assertEquals(2, $result[0]['numPhones']);
@@ -471,9 +471,9 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result);
-        $this->assertInternalType('array', $result[0]);
-        $this->assertInternalType('array', $result[1]);
+        $this->assertIsArray($result);
+        $this->assertIsArray($result[0]);
+        $this->assertIsArray($result[1]);
 
         $this->assertInstanceOf(CmsUser::class, $result[0][$userEntityKey]);
         $this->assertInstanceOf(PersistentCollection::class, $result[0][$userEntityKey]->phonenumbers);
@@ -552,9 +552,9 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result);
-        $this->assertInternalType('array', $result[1]);
-        $this->assertInternalType('array', $result[2]);
+        $this->assertIsArray($result);
+        $this->assertIsArray($result[1]);
+        $this->assertIsArray($result[2]);
 
         // test the scalar values
         $this->assertEquals('ROMANB', $result[1]['nameUpper']);
@@ -985,8 +985,8 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result[0]);
-        $this->assertInternalType('array', $result[1]);
+        $this->assertIsArray($result[0]);
+        $this->assertIsArray($result[1]);
 
         $this->assertEquals(1, $result[0]['id']);
         $this->assertEquals('romanb', $result[0]['name']);
@@ -1090,7 +1090,7 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(1, count($result));
 
-        $this->assertInternalType('array', $result[0]);
+        $this->assertIsArray($result[0]);
         $this->assertInstanceOf(ECommerceProduct::class, $result[0]['product']);
     }
 
@@ -1213,10 +1213,10 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result[0]);
+        $this->assertIsArray($result[0]);
         $this->assertInstanceOf(CmsUser::class, $result[0]['user']);
 
-        $this->assertInternalType('array', $result[1]);
+        $this->assertIsArray($result[1]);
         $this->assertInstanceOf(CmsUser::class, $result[1]['user']);
 
         $this->assertEquals(0, $result[0]['user']->articles->count());
@@ -1550,9 +1550,9 @@ class ObjectHydratorTest extends HydrationTestCase
 
         $this->assertEquals(2, count($result));
 
-        $this->assertInternalType('array', $result[0]);
+        $this->assertIsArray($result[0]);
         $this->assertInstanceOf(CmsUser::class, $result[0]['user']);
-        $this->assertInternalType('array', $result[1]);
+        $this->assertIsArray($result[1]);
         $this->assertInstanceOf(CmsUser::class, $result[1]['user']);
 
         $this->assertEquals(2, count($result[0]['user']->groups));
@@ -1822,12 +1822,11 @@ class ObjectHydratorTest extends HydrationTestCase
 
     /**
      * @group DDC-1470
-     *
-     * @expectedException \Doctrine\ORM\Internal\Hydration\HydrationException
-     * @expectedExceptionMessage The meta mapping for the discriminator column "c_discr" is missing for "Doctrine\Tests\Models\Company\CompanyFixContract" using the DQL alias "c".
      */
     public function testMissingMetaMappingException()
     {
+        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectExceptionMessage('The meta mapping for the discriminator column "c_discr" is missing for "Doctrine\Tests\Models\Company\CompanyFixContract" using the DQL alias "c".');
         $rsm = new ResultSetMapping;
 
         $rsm->addEntityResult(CompanyFixContract::class, 'c');
@@ -1849,12 +1848,11 @@ class ObjectHydratorTest extends HydrationTestCase
 
     /**
      * @group DDC-1470
-     *
-     * @expectedException \Doctrine\ORM\Internal\Hydration\HydrationException
-     * @expectedExceptionMessage The discriminator column "discr" is missing for "Doctrine\Tests\Models\Company\CompanyEmployee" using the DQL alias "e".
      */
     public function testMissingDiscriminatorColumnException()
     {
+        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectExceptionMessage('The discriminator column "discr" is missing for "Doctrine\Tests\Models\Company\CompanyEmployee" using the DQL alias "e".');
         $rsm = new ResultSetMapping;
 
         $rsm->addEntityResult(CompanyFixContract::class, 'c');
@@ -1883,12 +1881,11 @@ class ObjectHydratorTest extends HydrationTestCase
 
     /**
      * @group DDC-3076
-     *
-     * @expectedException \Doctrine\ORM\Internal\Hydration\HydrationException
-     * @expectedExceptionMessage The discriminator value "subworker" is invalid. It must be one of "person", "manager", "employee".
      */
     public function testInvalidDiscriminatorValueException()
     {
+        $this->expectException('Doctrine\ORM\Internal\Hydration\HydrationException');
+        $this->expectExceptionMessage('The discriminator value "subworker" is invalid. It must be one of "person", "manager", "employee".');
         $rsm = new ResultSetMapping;
 
         $rsm->addEntityResult(CompanyPerson::class, 'p');
