@@ -15,7 +15,7 @@ class LanguageRecognitionTest extends OrmTestCase
      */
     private $_em;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->_em = $this->_getTestEntityManager();
     }
