@@ -7,6 +7,7 @@ use Doctrine\Common\Cache\ArrayCache;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\ORM\Internal\Hydration\IterableResult;
+use Doctrine\ORM\Query;
 use Doctrine\ORM\Query\Parameter;
 use Doctrine\ORM\Query\QueryException;
 use Doctrine\ORM\UnitOfWork;
@@ -17,13 +18,14 @@ use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\Models\Generic\DateTimeModel;
 use Doctrine\Tests\OrmTestCase;
+use ReflectionClass;
 
 class QueryTest extends OrmTestCase
 {
     /** @var EntityManagerMock */
     protected $_em;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->_em = $this->_getTestEntityManager();
     }
@@ -132,20 +134,16 @@ class QueryTest extends OrmTestCase
         $this->assertSame($this->_em->getConfiguration()->getResultCacheImpl(), $q->getQueryCacheProfile()->getResultCacheDriver());
     }
 
-    /**
-     * @expectedException Doctrine\ORM\Query\QueryException
-     **/
     public function testIterateWithNoDistinctAndWrongSelectClause()
     {
+        $this->expectException('Doctrine\ORM\Query\QueryException');
         $q = $this->_em->createQuery("select u, a from Doctrine\Tests\Models\CMS\CmsUser u LEFT JOIN u.articles a");
         $q->iterate();
     }
 
-    /**
-     * @expectedException Doctrine\ORM\Query\QueryException
-     **/
     public function testIterateWithNoDistinctAndWithValidSelectClause()
     {
+        $this->expectException('Doctrine\ORM\Query\QueryException');
         $q = $this->_em->createQuery("select u from Doctrine\Tests\Models\CMS\CmsUser u LEFT JOIN u.articles a");
         $q->iterate();
     }
@@ -400,7 +398,10 @@ class QueryTest extends OrmTestCase
         $query->enableResultCache();
         $query->setResultCacheProfile();
 
-        self::assertAttributeSame(null, '_queryCacheProfile', $query);
+        $class    = new ReflectionClass(Query::class);
+        $property = $class->getProperty('_queryCacheProfile');
+        $property->setAccessible(true);
+        self::assertNull($property->getValue($query));
     }
 
     /** @group 7527 */
