@@ -26,7 +26,7 @@ class EntityGeneratorTest extends OrmTestCase
     private $_tmpDir;
     private $_namespace;
 
-    public function setUp()
+    protected function setUp() : void
     {
         $this->_namespace = uniqid("doctrine_");
         $this->_tmpDir = \sys_get_temp_dir();
@@ -40,7 +40,7 @@ class EntityGeneratorTest extends OrmTestCase
         $this->_generator->setFieldVisibility(EntityGenerator::FIELD_VISIBLE_PROTECTED);
     }
 
-    public function tearDown()
+    public function tearDown() : void
     {
         $ri = new \RecursiveIteratorIterator(new \RecursiveDirectoryIterator($this->_tmpDir . '/' . $this->_namespace));
         foreach ($ri AS $file) {
@@ -247,7 +247,7 @@ class EntityGeneratorTest extends OrmTestCase
 
         $docComment = $refClass->getProperty('testEmbedded')->getDocComment();
         $needle = sprintf('@Embedded(class="%s", columnPrefix="%s")', $testMetadata->name, $columnPrefix);
-        self::assertContains($needle, $docComment);
+        self::assertStringContainsString($needle, $docComment);
     }
 
     /**
@@ -263,7 +263,7 @@ class EntityGeneratorTest extends OrmTestCase
 
         $docComment = $refClass->getProperty('testEmbedded')->getDocComment();
         $needle = sprintf('@Embedded(class="%s", columnPrefix=false)', $testMetadata->name);
-        self::assertContains($needle, $docComment);
+        self::assertStringContainsString($needle, $docComment);
     }
 
     public function testGeneratedEntityClass()
@@ -314,7 +314,7 @@ class EntityGeneratorTest extends OrmTestCase
         $this->assertInstanceOf($metadata->name, $book->addComment($comment));
         $this->assertInstanceOf(ArrayCollection::class, $book->getComments());
         $this->assertEquals(new ArrayCollection([$comment]), $book->getComments());
-        $this->assertInternalType('boolean', $book->removeComment($comment));
+        $this->assertIsBool($book->removeComment($comment));
         $this->assertEquals(new ArrayCollection([]), $book->getComments());
 
         $this->newInstance($isbnMetadata);
@@ -609,10 +609,13 @@ class EntityGeneratorTest extends OrmTestCase
         $reflection = new \ReflectionProperty($metadata->name, 'id');
         $docComment = $reflection->getDocComment();
 
-        $this->assertContains('@Id', $docComment);
-        $this->assertContains('@Column(name="id", type="integer")', $docComment);
-        $this->assertContains('@GeneratedValue(strategy="SEQUENCE")', $docComment);
-        $this->assertContains('@SequenceGenerator(sequenceName="DDC1784_ID_SEQ", allocationSize=1, initialValue=2)', $docComment);
+        $this->assertStringContainsString('@Id', $docComment);
+        $this->assertStringContainsString('@Column(name="id", type="integer")', $docComment);
+        $this->assertStringContainsString('@GeneratedValue(strategy="SEQUENCE")', $docComment);
+        $this->assertStringContainsString(
+            '@SequenceGenerator(sequenceName="DDC1784_ID_SEQ", allocationSize=1, initialValue=2)',
+            $docComment
+        );
     }
 
     /**
@@ -653,11 +656,23 @@ class EntityGeneratorTest extends OrmTestCase
         $docComment = $property->getDocComment();
 
         //joinColumns
-        $this->assertContains('@JoinColumn(name="idorcamento", referencedColumnName="idorcamento"),', $docComment);
-        $this->assertContains('@JoinColumn(name="idunidade", referencedColumnName="idunidade")', $docComment);
+        $this->assertStringContainsString(
+            '@JoinColumn(name="idorcamento", referencedColumnName="idorcamento"),',
+            $docComment
+        );
+        $this->assertStringContainsString(
+            '@JoinColumn(name="idunidade", referencedColumnName="idunidade")',
+            $docComment
+        );
         //inverseJoinColumns
-        $this->assertContains('@JoinColumn(name="idcentrocusto", referencedColumnName="idcentrocusto"),', $docComment);
-        $this->assertContains('@JoinColumn(name="idpais", referencedColumnName="idpais")', $docComment);
+        $this->assertStringContainsString(
+            '@JoinColumn(name="idcentrocusto", referencedColumnName="idcentrocusto"),',
+            $docComment
+        );
+        $this->assertStringContainsString(
+            '@JoinColumn(name="idpais", referencedColumnName="idpais")',
+            $docComment
+        );
 
     }
 
@@ -1233,7 +1248,7 @@ class
         $property   = new \ReflectionProperty($metadata->name, 'test');
         $docComment = $property->getDocComment();
 
-        self::assertContains($expectedAnnotation, $docComment);
+        self::assertStringContainsString($expectedAnnotation, $docComment);
     }
 
     public function columnOptionsProvider() : array
