@@ -19,6 +19,7 @@ use Doctrine\Tests\DbalTypes\Rot13Type;
 use Doctrine\Tests\EventListener\CacheMetadataListener;
 use Doctrine\Tests\Models;
 use PHPUnit\Framework\AssertionFailedError;
+use Throwable;
 
 /**
  * Base testcase class for all functional ORM testcases.
@@ -330,7 +331,7 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
      *
      * @return void
      */
-    protected function tearDown()
+    protected function tearDown() : void
     {
         $conn = static::$_sharedConn;
 
@@ -639,7 +640,7 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
      *
      * @return void
      */
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->setUpDBALTypes();
 
@@ -782,13 +783,9 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
     }
 
     /**
-     * @param \Throwable $e
-     *
-     * @return void
-     *
      * @throws \Throwable
      */
-    protected function onNotSuccessfulTest(\Throwable $e)
+    protected function onNotSuccessfulTest(Throwable $e) : void
     {
         if ($e instanceof AssertionFailedError) {
             throw $e;
